@@ -47,9 +47,9 @@ summary.MixtCompLearn <- function(object, nClass = NULL, ...)
   
   if(!is.null(nClass) && (nClass[1] %in% object$nClass))
   {
-    RMixtCompUtilities:::summary.MixtComp(object$res[[which(object$nClass == nClass[1])]])
+    summary(object$res[[which(object$nClass == nClass[1])]])
   }else{
-    RMixtCompUtilities:::summary.MixtComp(object)
+    summary(object$res[[which(object$nClass == object$algo$nClass)]])
   }
 }
 
@@ -90,10 +90,10 @@ print.MixtCompLearn <- function(x, nVarMaxToPrint = 5, nClass = NULL, ...)
   if(!is.null(nClass) && (nClass[1] %in% x$nClass))
   {
     cat(paste0("\n Result for ", nClass[1], " classes\n"))
-    RMixtCompUtilities:::print.MixtComp(x$res[[which(x$nClass == nClass[1])]], nVarMaxToPrint = nVarMaxToPrint)
+    print(x$res[[which(x$nClass == nClass[1])]], nVarMaxToPrint = nVarMaxToPrint)
   }else{
     cat("\n Best result\n")
-    RMixtCompUtilities:::print.MixtComp(x, nVarMaxToPrint = nVarMaxToPrint)
+    print(x$res[[which(x$nClass == x$algo$nClass)]], nVarMaxToPrint = nVarMaxToPrint)
   }
   cat("\n $res: results from all MixtComp Run\n")
 }
