@@ -12,7 +12,7 @@
 # 
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <https://www.gnu.org/licenses/>
- 
+
 
 #' @title Learn and predict using RMixtComp
 #' 
@@ -23,7 +23,7 @@
 #' @param algo a list containing the parameters of the SEM-Gibbs algorithm (see \emph{Details} or \link{createAlgo}).
 #' @param nClass the number of classes of the mixture model. Can be a vector for \emph{mixtCompLearn} only.
 #' @param criterion "BIC" or "ICL". Criterion used for choosing the best model.
-#' @param hierarchicalMode "auto", "yes" or "no". If "auto", it performs a hierarchical version of MixtComp (clustering in two classes then each classes is split in two ...) when a functional variable is present.
+#' @param hierarchicalMode "auto", "yes" or "no". If "auto", it performs a hierarchical version of MixtComp (clustering in two classes then each classes is split in two ...) when a functional variable is present (see section \emph{Hierarchical Mode}).
 #' @param nRun number of runs for every given number of class. If >1, SEM is run \code{nRun} times for every number of class, and the best according to observed likelihood is kept.
 #' @param nCore number of cores used for the parallelization of the \emph{nRun} runs.
 #' @param resLearn output of \emph{mixtCompLearn} (only for \emph{mixtCompPredict} function).
@@ -71,7 +71,7 @@
 #' 
 #' 
 #' @section Data format:
-#' See \url{https://github.com/modal-inria/MixtComp/blob/master/MixtComp/docs/dataFormat.md}.
+#' See the associated vignette for more details (\code{RShowDoc("dataFormat", package = "RMixtComp")}).
 #' 
 #' - Gaussian data:
 #' Gaussian data are real values with the dot as decimal separator.
@@ -219,13 +219,29 @@
 #'
 #' }                  
 #'
-#' See \url{https://github.com/modal-inria/MixtComp/blob/master/MixtComp/docs/objectOutput.md}
+#' See the associated vignette for more details: \code{RShowDoc("mixtCompObject", package = "RMixtComp")}
 #'
 #' @section MixtCompLearn object:
-#' The MixtCompLearn object is the result of a run of the \emph{mixtCompLearn} function. It is a list containing \emph{nClass}: the vector of number of classes given by user, \emph{res} a list of MixtComp object (one per element of \emph{nbClass}),
-#' \emph{criterion} the criterion used to choose the best model, \emph{crit} a matrix containing BIC and ICL for each run, and finally the elements of the MixtComp object with the best criterion value (\emph{algo}, \emph{mixture}, \emph{variable} or \emph{warnLog}). 
+#' The MixtCompLearn object is the result of a run of the \emph{mixtCompLearn} function. 
+#' It is a list containing \emph{nClass}: the vector of number of classes given by user, \emph{res} a list of MixtComp object (one per element of \emph{nbClass}),
+#' \emph{criterion} the criterion used to choose the best model, \emph{crit} a matrix containing BIC and ICL for each run, \emph{totalTime}, the total running time, 
+#' and finally the elements of the MixtComp object with the best criterion value (\emph{algo}, \emph{mixture}, \emph{variable} or \emph{warnLog}). 
+#'
+#'
+#' @section Hierarchical Mode:
+#' When the \code{model}'s parameter includes a functional model (\code{Func_CS} or \code{Func_SharedAlpha_CS}), The algorithm is automatically run in "Hierarchical Mode".
+#' In hierarchical mode, it first clusters the data in 2 classes. Then, it searches the best model in 3 classes by performing a clustering in 2 classes of each class of the previous step).
+#' The same process is used until the asked number (\emph{K}) of classes is attained.
+#' All models from 2 to \emph{K} classes are returned (even if the case \code{nClass = K}).
+#' 
+#' This strategy is used to solve some problem (initialization, empty classes...) when the number of classes is high with the functional model.
+#' 
+#' The user can control the activation of the hierarchical mode using the \code{hierarchicalMode}'s parameter. 
+#' Three values are possible: \code{"no"}, the algorithm is never run in hierarchical mode, \code{"yes"}, the algorithm is always run in hierarchical mode, and \code{"auto"}, 
+#' the algorithm is run in hierarchical mode only when there is at least one functional variable (default).
+#' 
+#' 
 #'
-#'                   
 #' @references 
 #' Julien Jacques, Christophe Biernacki. \emph{Model-based clustering for multivariate partial ranking data}. Journal of Statistical Planning and Inference, Elsevier, 2014, 149, pp.201-217.
 #' 
@@ -276,7 +292,7 @@ mixtCompLearn <- function(data, model = NULL, algo = createAlgo(), nClass, crite
     model <- imputModel(data)
   }else{
     mode <- "expert"
-    model <- RMixtCompUtilities:::formatModel(model)  
+    model <- formatModel(model)  
   }
   
   performHier <- performHierarchical(hierarchicalMode, mode, model)
@@ -289,9 +305,11 @@ mixtCompLearn <- function(data, model = NULL, algo = createAlgo(), nClass, crite
     resLearn <- classicLearn(data, model, algo, nClass, criterion, nRun, nCore, verbose, mode)
   t2 <- proc.time()
   
+  resLearn$totalTime <- (t2-t1)[3]
+  
   if(verbose)
   {
-    cat(paste0("Total runtime: ", round((t2-t1)[3], 3), "s\n"))
+    cat(paste0("Total runtime: ", round(resLearn$totalTime, 3), "s\n"))
     if(is.null(resLearn$warnLog))
       cat(paste0("Best model according to ", criterion, ": ", resLearn$algo$nClass," clusters.\n"))
     else
@@ -311,14 +329,14 @@ mixtCompPredict <- function(data, model = NULL, algo = resLearn$algo, resLearn,
   if(is.null(model))
     model = getModel(resLearn, with.z_class = FALSE)
   
-  model = RMixtCompUtilities:::formatModel(model)
+  model = formatModel(model)
   
   
   if(resLearn$algo$basicMode)
   {
     dataList <- formatDataBasicMode(data, model, resLearn$algo$dictionary)$data
   }else{
-    dataList <- RMixtCompUtilities:::formatData(data)
+    dataList <- formatData(data)
   }
   
   
@@ -326,7 +344,7 @@ mixtCompPredict <- function(data, model = NULL, algo = resLearn$algo, resLearn,
   algo$nClass = checkNClass(nClass, resLearn)
   algo$mode = "predict"
   
-  algo = RMixtCompUtilities:::completeAlgo(algo)
+  algo = completeAlgo(algo)
   
   ## run predict
   if("MixtCompLearn" %in% class(resLearn))
@@ -426,14 +444,14 @@ classicLearn <- function(data, model, algo, nClass, criterion, nRun, nCore, verb
     }
     
   }else{
-    dataList <- RMixtCompUtilities:::formatData(data)
+    dataList <- formatData(data)
     model <- completeModel(model, dataList)
   }
   
   algo$nInd = length(dataList[[1]])
   algo$mode = "learn"
   
-  algo = RMixtCompUtilities:::completeAlgo(algo)
+  algo = completeAlgo(algo)
   
   indCrit <- ifelse(criterion == "BIC", 1, 2)
   
@@ -495,13 +513,13 @@ hierarchicalLearn <- function(data, model, algo, nClass, criterion, minClassSize
   
   nClass <- max(nClass)
   
-  dataList <- RMixtCompUtilities:::formatData(data)
+  dataList <- formatData(data)
   model <- completeModel(model, dataList)
   
   algo$nInd = length(dataList[[1]])
   algo$mode = "learn"
   
-  algo = RMixtCompUtilities:::completeAlgo(algo)
+  algo = completeAlgo(algo)
   
   resLearn <- hierarchicalMixtCompLearn(data, model, algo, nClass, criterion, minClassSize, nRun, nCore, verbose)
   
